@@ -839,8 +839,8 @@ class AstroLink:
         model (with model-fitted parameters) is then used alongside the standard 
         normal distribution to transform prominence values into statistical 
         significance values. The noise model is chosen from among the Beta, 
-        Half-normal, and Log-normal distributions using the second-order Akaike 
-        Information Criterion (AICc).
+        Truncated-normal, and Log-normal distributions using the second-order 
+        Akaike Information Criterion (AICc).
 
         The method requires the `prominences` attribute to have already been 
         created, via the `aggregate` method or otherwise.
@@ -859,12 +859,15 @@ class AstroLink:
         self._modelSuccess = np.ones(self._modelAICc.size, dtype = np.bool_)
         for i, (negLL, params, args, bounds) in enumerate(zip(modelNegLLs, self._modelParams, modelArgs, modelBounds)):
             sol = minimize(negLL, params, args = tuple(args), jac = '3-point', bounds = tuple(bounds), tol = tol)
-            if sol.success: self._modelParams[i] = sol.x
-            else: self._modelSuccess[i] = False
-            self._modelAICc[i] += 2*sol.fun
+            if sol.success:
+                self._modelParams[i] = sol.x
+                self._modelAICc[i] += 2*sol.fun
+            else:
+                self._modelSuccess[i] = False
+                self._modelAICc[i] = np.inf
         del modelNegLLs, modelArgs, modelBounds, tol
 
-        if not self._modelSuccess.any(): self._printFunction('[Warning] Prominence model may be incorrectly fitted!', returnLine = False, urgent = True)
+        if not self._modelSuccess.any(): self._printFunction('[Warning] Prominence model is incorrectly fitted!', returnLine = False, urgent = True)
 
         # Choose the best model and calculate statistical significance values
         bestModel = np.argmin(self._modelAICc)
@@ -885,7 +888,7 @@ class AstroLink:
     def _minimize_init_njit(prominences):
         # Precalculated properties of the prominence values
         promOrd = np.sort(prominences)
-        cutOff = promOrd[int(0.6*promOrd.size)]
+        cutOff = promOrd[int(0.99*promOrd.size)]
         mu, var = promOrd.mean(), promOrd.var()
         tol = min(1e-5, 10**(-np.ceil(np.log10(prominences.size)) + 1))
         
@@ -901,12 +904,16 @@ class AstroLink:
         # For Beta model
         term1 = 1 - mu
         term2 = mu*term1/var - 1
-        modelParams = [np.array([cutOff, term2*mu, term2*term1])]
+        a, b = mu*term2, term1*term2
+        if a < 1:
+            b /= a
+            a = 1 + tol
+        modelParams = [np.array([cutOff, a, b])]
         modelArgs = [[promOrdOpenBorder, lnx_cumsum, ln_1_minus_x_cumsum]]
         modelBounds = [[(tol, 1 - tol), (1 + tol, np.inf), (1, np.inf)]]
         
         # For truncated-normal model
-        modelParams.append(np.array([cutOff, promOrd[int(0.1*promOrd.size)], np.sqrt(np.pi/2)*mu]))
+        modelParams.append(np.array([cutOff, 0, np.sqrt(var/(1 - 2/np.pi))]))
         modelArgs.append([promOrd, x_cumsum, x_sqrd_cumsum])
         modelBounds.append([(tol, 1 - tol), (0, np.inf), (tol, np.inf)])
         
@@ -935,18 +942,18 @@ class AstroLink:
         n = promOrdOpenBorder.size
 
         # Calculate constant terms
-        uniform_term = (c**(a - 1))*((1 - c)**(b - 1))
-        normalisationFactor = norm_constant + uniform_term*(1 - c)
+        log_uniform_term = (a - 1)*np.log(c) + (b - 1)*np.log(1 - c)
+        normalisationFactor = norm_constant + (1 - c)*np.exp(log_uniform_term)
 
         # Find the index of the first prominence that is greater than c
-        transitionPoint, right = 0, lnx_cumsum.size - 1
+        transitionPoint, right = 0, n - 1
         while right - transitionPoint > 1:
             middle = (right - transitionPoint)//2 + transitionPoint
             if promOrdOpenBorder[middle] < c: transitionPoint = middle
             else: right = middle
         
         # Calculate and return the negative log-likelihood
-        return n*np.log(normalisationFactor) - (a - 1)*lnx_cumsum[transitionPoint] - (b - 1)*ln_1_minus_x_cumsum[transitionPoint] - (n - transitionPoint - 1)*np.log(uniform_term)
+        return n*np.log(normalisationFactor) - (a - 1)*lnx_cumsum[transitionPoint] - (b - 1)*ln_1_minus_x_cumsum[transitionPoint] - (n - transitionPoint - 1)*log_uniform_term
 
     def _negLL_truncatednormal(self, p, promOrd, x_cumsum, x_sqrd_cumsum):
         # Calculate the negative log-likelihood
